==> lxqt-l10n-0.11.0-1-src.tar.xz: lxqt-l10n-0.11.0/lxqt-panel/plugin-quicklaunch/quicklaunch_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="213"/>
        <source>Drop Error</source>
        <translation>Neerzetfout</translation>
    </message>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="214"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Bestand/URL &apos;%1&apos; kan vooralsnog niet worden ingebed in de snelstartbalk</translation>
    </message>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="320"/>
        <source>Drop application
icons here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="55"/>
        <source>Move left</source>
        <translation>Verplaats naar links</translation>
    </message>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="58"/>
        <source>Move right</source>
        <translation>Verplaats naar rechts</translation>
    </message>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="62"/>
        <source>Remove from quicklaunch</source>
        <translation>Verwijder uit snelstartbalk</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.12.0-1-src.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-quicklaunch/quicklaunch_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="213"/>
        <source>Drop Error</source>
        <translation>Neerzetfout</translation>
    </message>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="214"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Bestand/URL &apos;%1&apos; kan vooralsnog niet worden ingebed in de snelstartbalk</translation>
    </message>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="320"/>
        <source>Drop application
icons here</source>
        <translation>Zet pictogrammen van
toepassingen hier neer</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="55"/>
        <source>Move left</source>
        <translation>Verplaats naar links</translation>
    </message>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="58"/>
        <source>Move right</source>
        <translation>Verplaats naar rechts</translation>
    </message>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="62"/>
        <source>Remove from quicklaunch</source>
        <translation>Verwijder uit snelstartbalk</translation>
    </message>
</context>
</TS>
